
.. py:currentmodule:: pythreejs

AnimationMixer
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: AnimationMixer(rootObject=None, time=0, timeScale=1, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.ThreeWidget`.

    Three.js docs: https://threejs.org/docs/#api/animation/AnimationMixer


    .. py:attribute:: rootObject

        .. sourcecode:: python

            Instance(ThreeWidget, allow_none=True).tag(sync=True, **widget_serialization)

    .. py:attribute:: time

        .. sourcecode:: python

            CFloat(0, allow_none=False).tag(sync=True)

    .. py:attribute:: timeScale

        .. sourcecode:: python

            CFloat(1, allow_none=False).tag(sync=True)

